//===- XCoreSubtarget.cpp - XCore Subtarget Information -----------*- C++ -*-=//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//
//
// This file implements the XCore specific subclass of TargetSubtarget.
//
//===----------------------------------------------------------------------===//

#include "XCoreSubtarget.h"
#include "XCore.h"
using namespace llvm;

XCoreSubtarget::XCoreSubtarget(const std::string &TT, const std::string &FS)
{
}
